@@ -20,16 +20,17 @@ sys.path.insert(0, BASE_DIR)
 from argparse import SUPPRESS, ArgumentParser  # noqa: E402
 
 import argcomplete  # noqa: E402
+import argcomplete.io  # noqa: E402
 from argcomplete import (  # noqa: E402
     CompletionFinder,
     ExclusiveCompletionFinder,
     _check_module,
     autocomplete,
     shellcode,
-    split_line,
     warn,
 )
 from argcomplete.completers import DirectoriesCompleter, FilesCompleter, SuppressCompleter  # noqa: E402
+from argcomplete.lexers import _split_line  # noqa: E402
 
 IFS = "\013"
 COMP_WORDBREAKS = " \t\n\"'><=;|&(:"
@@ -498,16 +499,6 @@ class TestArgcomplete(unittest.TestCase):
         self.assertEqual("help for rover ", disp.get("sojourner", ""))
         self.assertEqual("", disp.get("low gain", ""))
 
-        completer.rl_complete('opportunity "low gain" list ', 0)
-        disp = completer.get_display_completions()
-        self.assertEqual("ttt", disp.get("-o --oh", ""))
-        self.assertEqual("list cat", disp.get("cat", ""))
-
-        completer.rl_complete("opportunity low\\ gain list --", 0)
-        disp = completer.get_display_completions()
-        self.assertEqual("ttt", disp.get("--oh", ""))
-        self.assertEqual("ccc", disp.get("--ch", ""))
-
     def test_display_completions_with_aliases(self):
         parser = ArgumentParser()
         parser.add_subparsers().add_parser("a", aliases=["b", "c"], help="abc help")
@@ -516,31 +507,34 @@ class TestArgcomplete(unittest.TestCase):
         completer = CompletionFinder(parser)
         completer.rl_complete("", 0)
         disp = completer.get_display_completions()
-        self.assertEqual({"a b c": "abc help", "-h --help": "show this help message and exit"}, disp)
+        self.assertEqual(
+            {
+                "a": "abc help",
+                "b": "abc help",
+                "c": "abc help",
+                "-h": "show this help message and exit",
+                "--help": "show this help message and exit",
+            },
+            disp,
+        )
 
         # a
         completer = CompletionFinder(parser)
         completer.rl_complete("a", 0)
         disp = completer.get_display_completions()
-        self.assertEqual({"a": "abc help", "": "show this help message and exit"}, disp)
+        self.assertEqual({"a": "abc help"}, disp)
 
         # b
         completer = CompletionFinder(parser)
         completer.rl_complete("b", 0)
         disp = completer.get_display_completions()
-        self.assertEqual({"b": "abc help", "": "show this help message and exit"}, disp)
+        self.assertEqual({"b": "abc help"}, disp)
 
         # c
         completer = CompletionFinder(parser)
         completer.rl_complete("c", 0)
         disp = completer.get_display_completions()
-        self.assertEqual({"c": "abc help", "": "show this help message and exit"}, disp)
-
-        # (
-        completer = CompletionFinder(parser)
-        completer.rl_complete("(", 0)
-        disp = completer.get_display_completions()
-        self.assertEqual({"": "show this help message and exit"}, disp)
+        self.assertEqual({"c": "abc help"}, disp)
 
     def test_nargs_one_or_more(self):
         def make_parser():
@@ -841,7 +835,7 @@ class TestArgcompleteREPL(unittest.TestCase):
         pass
 
     def run_completer(self, parser, completer, command, point=None, **kwargs):
-        cword_prequote, cword_prefix, cword_suffix, comp_words, first_colon_pos = split_line(command)
+        cword_prequote, cword_prefix, cword_suffix, comp_words, first_colon_pos = _split_line(command)
 
         completions = completer._get_completions(comp_words, cword_prefix, cword_prequote, first_colon_pos)
 
@@ -953,10 +947,10 @@ class TestSplitLine(unittest.TestCase):
         os.environ = self._os_environ
 
     def prefix(self, line):
-        return split_line(line)[1]
+        return _split_line(line)[1]
 
     def wordbreak(self, line):
-        return split_line(line)[4]
+        return _split_line(line)[4]
 
     def test_simple(self):
         self.assertEqual(self.prefix("a b c"), "c")
@@ -1335,12 +1329,12 @@ class Warn(unittest.TestCase):
     def test_warn(self):
         @contextlib.contextmanager
         def redirect_debug_stream(stream):
-            debug_stream = argcomplete.debug_stream
-            argcomplete.debug_stream = stream
+            debug_stream = argcomplete.io.debug_stream
+            argcomplete.io.debug_stream = stream
             try:
                 yield
             finally:
-                argcomplete.debug_stream = debug_stream
+                argcomplete.io.debug_stream = debug_stream
 
         test_stream = StringIO()
         with redirect_debug_stream(test_stream):
